json

package
v1.16.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 4, 2026 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Overview

Package json is a drop-in replacement for encoding/json that delegates to github.com/goccy/go-json for better marshal/unmarshal performance. All public symbols required by the rest of the codebase are re-exported here so that callers only need to change their import path.

Index

Constants

This section is empty.

Variables

var (
	Marshal       = gojson.Marshal
	MarshalIndent = gojson.MarshalIndent
	Unmarshal     = gojson.Unmarshal
	NewDecoder    = gojson.NewDecoder
	NewEncoder    = gojson.NewEncoder
	Valid         = gojson.Valid
)

Functions

This section is empty.

Types

type Decoder

type Decoder = gojson.Decoder

type Encoder

type Encoder = gojson.Encoder

type InvalidUnmarshalError

type InvalidUnmarshalError = gojson.InvalidUnmarshalError

type Marshaler

type Marshaler = gojson.Marshaler

type MarshalerError

type MarshalerError = gojson.MarshalerError

type Number

type Number = gojson.Number

type RawMessage

type RawMessage = gojson.RawMessage

type SyntaxError

type SyntaxError = gojson.SyntaxError

type UnmarshalTypeError

type UnmarshalTypeError = gojson.UnmarshalTypeError

type Unmarshaler

type Unmarshaler = gojson.Unmarshaler

Jump to