Documentation
¶
Overview ¶
Package json is a drop-in replacement for encoding/json that delegates to github.com/goccy/go-json for better marshal/unmarshal performance. All public symbols required by the rest of the codebase are re-exported here so that callers only need to change their import path.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( Marshal = gojson.Marshal MarshalIndent = gojson.MarshalIndent Unmarshal = gojson.Unmarshal NewDecoder = gojson.NewDecoder NewEncoder = gojson.NewEncoder Valid = gojson.Valid )
Functions ¶
This section is empty.
Types ¶
type InvalidUnmarshalError ¶
type InvalidUnmarshalError = gojson.InvalidUnmarshalError
type MarshalerError ¶
type MarshalerError = gojson.MarshalerError
type RawMessage ¶
type RawMessage = gojson.RawMessage
type SyntaxError ¶
type SyntaxError = gojson.SyntaxError
type UnmarshalTypeError ¶
type UnmarshalTypeError = gojson.UnmarshalTypeError
type Unmarshaler ¶
type Unmarshaler = gojson.Unmarshaler
Click to show internal directories.
Click to hide internal directories.